pendingStream: Get the pending streams for a dataset

View source: R/dataset-stream.R

pendingStreamR Documentation

Get the pending streams for a dataset

Description

Retrieves the number of pending messages. Use appendStream() to append all pending streamed rows to the dataset.

Usage

pendingStream(ds)

Arguments

ds

a CrunchDataset

Value

number of pending messages in the stream for the dataset


crunch documentation built on July 29, 2026, 1:06 a.m.