Learn R Programming

crunch (version 1.16.0)

projects: Get the project catalog

Description

Get the project catalog

Usage

projects(x = getAPIRoot())

Arguments

x

a ShojiObject that has a project catalog associated. If omitted, the default value for x means that you will load the user's primary project catalog. (Currently, there are no other project catalogs to load.)

Value

An object of class ProjectCatalog.

Examples

Run this code

myprojects <- projects()
proj <- myprojects[["Project name"]]

Run the code above in your browser using DataLab