crunch uses the jsonlite package for (de)serialization of
JSON. Unlike RJSONIO's toJSON, toJSON
does not allow for defining S4 methods for other object types. So,
crunch::toJSON wraps jsonprep, which exists to translate
objects to base R objects, which jsonlite::toJSON can handle.
jsonprep is defined as an S4 generic, and it is exported (unlike
codejsonlite::asJSON), so you can define methods for it if you have other
objects that you want to successfully serialize to JSON.
jsonprep(x, ...)# S4 method for Categories
jsonprep(x, ...)
# S4 method for list
jsonprep(x, ...)
# S4 method for ANY
jsonprep(x, ...)
# S4 method for ShojiOrder
jsonprep(x, ...)
# S4 method for OrderGroup
jsonprep(x, ...)
toJSON(x, ...)
the object
additional arguments
jsonprep returns a base R object that jsonlite::toJSON
can handle. toJSON returns the JSON-serialized character object.